api/ai/ai_transcriber_store library

Classes

AITranscriberStore
AI real-time transcription related interfaces, managing real-time speech-to-text transcription and translation features.
AITranscriberStoreImpl
AITranscriberStoreListener
AI transcriber event callback.
InterpretationConfig
Configuration for interpretation features.
TranscriberConfig
Transcription configuration, used to configure source language and translation languages.
TranscriberMessage
Transcription message, representing a single segment of transcribed speech.
TranscriberState
Transcription state data provided by AITranscriberStore.
TranscriptionConfig
Configuration for transcription features.

Enums

InterpretationVoice
Voice type for interpretation.
MessageListChangeType
SourceLanguage
Source language type for transcription recognition.
TranslationLanguage
Target language type for translation.