api/barrage/barrage_store library
Classes
- Barrage
- Barrage data model, containing complete attribute information of a single barrage.
- BarrageState
- Barrage state, managing the barrage data state of the current room.
- BarrageStore
- Barrage related interfaces, managing barrage sending, barrage state synchronization, and barrage event listening in live rooms/voice chat rooms.
Enums
- BarrageType
- Barrage type enumeration, used to distinguish different barrage message types.