CallEndReason enum
Call end reason, used to identify how the audio/video call ended (normal hangup, rejection, timeout, etc.).
This enum describes the various reasons why a call ended, helping developers understand how the call was terminated.
End Reason Description
| Reason | Description | Typical Scenario |
|---|---|---|
unknown |
Unknown reason | Unable to determine the end reason |
hangup |
Normal hangup | User actively hangs up the call |
reject |
Rejected | Callee rejects the incoming call |
noResponse |
No response | Callee did not answer within timeout |
offline |
Offline | Callee is offline |
lineBusy |
Line busy | Callee is already in a call |
canceled |
Canceled | Caller cancels before callee answers |
otherDeviceAccepted |
Accepted on another device | The call was picked up on another device associated with the same account. |
otherDeviceReject |
Rejected on another device | Call was rejected on another logged-in device |
endByServer |
Ended by server | Call was terminated by the server |
Values
- unknown → const CallEndReason
-
Unknown reason.
const CallEndReason(0) - hangup → const CallEndReason
-
Normal hangup.
const CallEndReason(1) - reject → const CallEndReason
-
Rejected.
const CallEndReason(2) - noResponse → const CallEndReason
-
No response.
const CallEndReason(3) - offline → const CallEndReason
-
Offline.
const CallEndReason(4) - lineBusy → const CallEndReason
-
Line busy.
const CallEndReason(5) - canceled → const CallEndReason
-
Call was canceled.
const CallEndReason(6) - otherDeviceAccepted → const CallEndReason
-
Accepted on another device.
const CallEndReason(7) - otherDeviceReject → const CallEndReason
-
Rejected on another device.
const CallEndReason(8) - endByServer → const CallEndReason
-
Call ended by backend.
const CallEndReason(9)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CallEndReason> - A constant List of the values in this enum, in order of their declaration.