CallParticipantInfo class

Call participant information, including user ID, nickname, avatar, participation status, microphone/camera on/off status, etc.

Contains complete information about a call participant including user ID, nickname, avatar, participation status, and device states.

Properties

avatarURL String
User avatar URL.
final
hashCode int
The hash code for this object.
no setterinherited
id String
User ID.
final
isCameraOpened bool
Whether camera is on.
final
isMicrophoneOpened bool
Whether microphone is on.
final
name String
User nickname.
final
remark String
Friend remark.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status CallParticipantStatus
Participant status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited