ContactInfo class

Constructors

ContactInfo({required String userID, String? avatarURL, String? nickname, String? aboutMe, ContactOnlineStatus onlineStatus = ContactOnlineStatus.unknown, bool isInBlacklist = false, bool isFriend = false, String? friendRemark})

Properties

aboutMe String?
getter/setter pair
avatarURL String?
getter/setter pair
friendRemark String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isFriend bool
getter/setter pair
isInBlacklist bool
getter/setter pair
nickname String?
getter/setter pair
onlineStatus ContactOnlineStatus
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userID String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited