ContactState class abstract

Constructors

ContactState()

Properties

blackList → ValueListenable<List<ContactInfo>>
no setter
friendApplicationList → ValueListenable<List<FriendApplicationInfo>>
no setter
friendApplicationUnreadCount → ValueListenable<int>
no setter
friendList → ValueListenable<List<ContactInfo>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited