FriendApplicationInfo class

Constructors

FriendApplicationInfo({required String userID, String? avatarURL, String? title, String? source, required FriendApplicationType type, String? addWording, V2TimFriendApplication? rawApplication})
const

Properties

addWording String?
final
avatarURL String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final
title String?
final
type FriendApplicationType
final
userID String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited