CompletionHandler class

Completion callback interface

Interface for asynchronous operation result callbacks. Calls onSuccess on success, onFailure on failure.

Property Type Description
errorCode int Error code
errorMessage String? Error message description
isSuccess bool Whether successful
Implementers

Constructors

CompletionHandler()

Properties

errorCode int
Error code.
getter/setter pair
errorMessage String?
Error message description.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
Whether successful.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited