VideoOrientation enum

Video orientation. Combined with VideoQuality to determine the final encoding resolution: landscape keeps the base resolution (width x height), portrait swaps the width and height.

This enum defines the orientation of the video encoding resolution. It must be used together with VideoQuality:

  • landscape (value 0): the encoding resolution keeps the base width and height, e.g. 1280 x 720.
  • portrait (value 1): the width and height are swapped, e.g. 720 x 1280.

For the resolution mapping of each level, see VideoQuality.

Inheritance
Available extensions

Values

landscape → const VideoOrientation

Landscape, the encoding resolution width is greater than the height (e.g. 1280 x 720).

const VideoOrientation(0)
portrait → const VideoOrientation

Portrait, the encoding resolution height is greater than the width (e.g. 720 x 1280).

const VideoOrientation(1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VideoOrientation>
A constant List of the values in this enum, in order of their declaration.