MusicPlayStatus enum

Music playback status.

Inheritance
Available extensions

Values

idle → const MusicPlayStatus

Idle, not playing.

const MusicPlayStatus(0)
playing → const MusicPlayStatus

Playing.

const MusicPlayStatus(1)
paused → const MusicPlayStatus

Paused.

const MusicPlayStatus(2)
loading → const MusicPlayStatus

Loading (e.g. buffering network resource).

const MusicPlayStatus(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MusicPlayStatus>
A constant List of the values in this enum, in order of their declaration.