Gift class

Gift data model, containing complete attribute information of a single gift.

Contains complete information about the gift including ID, name, description, icon, animation resource, etc.

Properties Overview

Property Type Description
giftID String Gift ID
name String Gift name
desc String Gift description
iconURL String Network URL of the gift icon image
resourceURL String Network URL of the gift animation resource file
level int Gift level
coins int Gift price (coins)
extensionInfo Map<String, String> Gift extension information

Constructors

Gift({String giftID = '', String name = '', String desc = '', String iconURL = '', String resourceURL = '', int level = 0, int coins = 0, Map<String, String> extensionInfo = const {}})

Properties

coins int
Gift price (coins)
final
desc String
Gift description
final
extensionInfo Map<String, String>
Gift extension information, customizable fields (such as effect type, sending restrictions, etc.)
final
giftID String
Gift ID
final
hashCode int
The hash code for this object.
no setterinherited
iconURL String
Network URL of the gift icon image, used to load gift thumbnails.
final
level int
Gift level, used to distinguish gift rarity or value tier.
final
name String
Gift name
final
resourceURL String
Network URL of the gift animation resource file, used to load gift display animations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited