GiftState class abstract

Gift state, managing the gift data state of the current room, supporting real-time updates and subscription listening.

Contains all gift categories and gift lists available in the current room, supporting real-time updates.

Note: Gift state is automatically updated. Subscribe to giftState to receive real-time updates.

Properties Overview

Property Type Description
usableGifts ValueListenable<List<GiftCategory>> All gift categories and gift lists available in the current room

Constructors

GiftState()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usableGifts ValueListenable<List<GiftCategory>>
All gift categories and gift lists available in the current room.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited