GroupCreateParams class

Constructors

GroupCreateParams({GroupType groupType = GroupType.work, required String groupName, String? groupID, String? avatarURL, List<String>? memberList})
const

Properties

avatarURL String?
final
groupID String?
final
groupName String
final
groupType GroupType
final
hashCode int
The hash code for this object.
no setterinherited
memberList List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited