GroupInfo class
Constructors
-
GroupInfo({required String groupID, String? groupName, String? avatarURL, GroupType? groupType, String? notification, GroupJoinOption? joinOption, GroupInviteOption? inviteOption, int? memberCount, bool? isAllMuted, String? groupOwner, GroupMemberRole? selfRole, Map<
String, String> ? groupAttributes})
Properties
- avatarURL ↔ String?
-
getter/setter pair
-
groupAttributes
↔ Map<
String, String> ? -
getter/setter pair
- groupID ↔ String
-
getter/setter pair
- groupName ↔ String?
-
getter/setter pair
- groupOwner ↔ String?
-
getter/setter pair
- groupType ↔ GroupType?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviteOption ↔ GroupInviteOption?
-
getter/setter pair
- isAllMuted ↔ bool?
-
getter/setter pair
- joinOption ↔ GroupJoinOption?
-
getter/setter pair
- memberCount ↔ int?
-
getter/setter pair
- notification ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfRole ↔ GroupMemberRole?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited