BattleEndedReason enum

Reason for PK ending received by users in an ongoing PK

This enum describes the reasons for PK ending.

Note: When the PK countdown ends or all members exit, the system will automatically trigger the PK end event.

Response Scenarios

Reason Value Description
timeOver 0 PK countdown ended
allMemberExit 1 All PK members exited
Inheritance
Available extensions

Values

timeOver → const BattleEndedReason

PK countdown ended.

const BattleEndedReason(0)
allMemberExit → const BattleEndedReason

All PK members exited.

const BattleEndedReason(1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BattleEndedReason>
A constant List of the values in this enum, in order of their declaration.