BattleState class abstract

PK-related state data provided by BattleStore

A comprehensive snapshot of the current PK session state. This structure contains all relevant information about current PK information, participating users, and scores.

Note: State is automatically updated when PK starts/ends, users join/exit PK, or scores are updated. Subscribe to battleState to receive real-time updates.

Property Type Description
currentBattleInfo ValueListenable<BattleInfo?> Current PK information
battleUsers ValueListenable<List<SeatUserInfo>> PK user list
battleScore ValueListenable<Map<String, int>> PK score mapping

Constructors

BattleState()

Properties

battleScore ValueListenable<Map<String, int>>
PK score mapping.
no setter
battleUsers ValueListenable<List<SeatUserInfo>>
PK user list.
no setter
currentBattleInfo ValueListenable<BattleInfo?>
Current PK information.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited