LikeState class abstract
Like state, used to display and subscribe to like information in live rooms/voice chat rooms.
Contains the total accumulated like count of the current live room/voice chat room, supporting real-time updates.
Note: Like count updates automatically. Subscribe to
likeStateto receive real-time updates.
State Properties Overview
| Property | Type | Description |
|---|---|---|
| totalLikeCount | ValueListenable<int> |
Total accumulated like count of the current room |
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
totalLikeCount
→ ValueListenable<
int> -
Total accumulated like count of the current live room/voice chat room, supporting real-time updates and subscription listening.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited