api/live/live_seat_store library
Classes
- AVStatistics
- Audio and video statistics information.
- LiveCanvas
- Live canvas.
- LiveSeatListener
- Seat related callback events.
- LiveSeatState
- Seat state data provided by LiveSeatStore.
- LiveSeatStore
- Live seat management related interfaces, managing seat operations such as taking seat, leaving seat, locking seat, and releasing seat.
- RegionInfo
- Seat view coordinate information.
- SeatInfo
- Seat information.
- SeatUserInfo
- Seat user information.
Enums
- DeviceControlPolicy
- Device control policy.
- MoveSeatPolicy
- Move seat policy.
- SuspendStatus
- User suspend status.