UserProfile class
User profile
User profile data structure, containing user ID, nickname, avatar, gender and other personal information.
User Profile Properties Overview
| Property | Type | Description |
|---|---|---|
| userID | String |
User ID |
| nickname | String? |
Nickname |
| avatarURL | String? |
Avatar URL |
| selfSignature | String? |
Personal signature |
| gender | Gender? |
Gender |
| role | int? |
Role |
| level | int? |
Level |
| birthday | int? |
Birthday |
| allowType | AllowType? |
Friend verification type |
| customInfo | Map<String, String>? |
Custom information |
Constructors
Properties
- allowType → AllowType?
-
Friend verification type.
final
- avatarURL → String?
-
Avatar URL.
final
- birthday → int?
-
Birthday.
final
-
customInfo
→ Map<
String, String> ? -
Custom information.
final
- gender → Gender?
-
Gender.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → int?
-
Level.
final
- nickname → String?
-
Nickname.
final
- role → int?
-
Role.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfSignature → String?
-
Personal signature.
final
- userID → String
-
User ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited