CallRejectionReason enum

Call rejection reason

Inheritance
Available extensions

Values

rejected → const CallRejectionReason

User actively rejected

const CallRejectionReason(0)
inOtherRoom → const CallRejectionReason

User in another room

const CallRejectionReason(1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEngineRejectedReason() → TUIInvitationRejectedReason

Available on CallRejectionReason, provided by the CallRejectionReasonExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CallRejectionReason>
A constant List of the values in this enum, in order of their declaration.