RoomInfo class

Room info

Represents complete room information, including basic info and configuration options.

Properties Overview

Property Type Description
roomID String Room ID
roomName String Room name
roomOwner RoomUser Room owner
participantCount int Participant count
roomStatus RoomStatus Room status
Available extensions

Constructors

RoomInfo({String roomID = '', String roomName = '', RoomUser? roomOwner, RoomType roomType = RoomType.standard, int participantCount = 0, int audienceCount = 0, int createTime = 0, RoomStatus roomStatus = RoomStatus.scheduled, int scheduledStartTime = 0, int scheduledEndTime = 0, int startReminderInSeconds = 0, List<RoomUser>? scheduleAttendees, String? password, bool isAllMicrophoneDisabled = false, bool isAllCameraDisabled = false, bool isAllMessageDisabled = false, bool isAllScreenShareDisabled = false})

Properties

audienceCount int
Audience count (for webinar room).
getter/setter pair
createTime int
Create time.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isAllCameraDisabled bool
Whether all cameras are disabled.
getter/setter pair
isAllMessageDisabled bool
Whether all messages are disabled.
getter/setter pair
isAllMicrophoneDisabled bool
Whether all microphones are disabled.
getter/setter pair
isAllScreenShareDisabled bool
Whether all screen sharing is disabled.
getter/setter pair
participantCount int
Participant count.
getter/setter pair
password String?
Room password.
getter/setter pair
roomID String
Room ID.
getter/setter pair
roomName String
Room name.
getter/setter pair
roomOwner RoomUser
Room owner.
getter/setter pair
roomStatus RoomStatus
Room status.
getter/setter pair
roomType RoomType
Room type.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleAttendees List<RoomUser>
Scheduled attendees list.
getter/setter pair
scheduledEndTime int
Scheduled end time.
getter/setter pair
scheduledStartTime int
Scheduled start time.
getter/setter pair
startReminderInSeconds int
Reminder seconds before start.
getter/setter pair

Methods

copyWith({String? roomID, String? roomName, RoomUser? roomOwner, RoomType? roomType, int? participantCount, int? audienceCount, int? createTime, RoomStatus? roomStatus, int? scheduledStartTime, int? scheduledEndTime, int? startReminderInSeconds, List<RoomUser>? scheduleAttendees, String? password, bool? isAllMicrophoneDisabled, bool? isAllCameraDisabled, bool? isAllMessageDisabled, bool? isAllScreenShareDisabled}) RoomInfo

Available on RoomInfo, provided by the RoomInfoExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateFromModifyFlags(RoomInfo source, List<TUIConferenceModifyFlag> flags) RoomInfo

Available on RoomInfo, provided by the RoomInfoExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited