RoomUser class

Room user info.

Represents basic information of a user in the room.

Constructors

RoomUser({String userID = '', String userName = '', String avatarURL = ''})

Properties

avatarURL ↔ String
User avatar URL.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userID ↔ String
User ID.
getter/setter pair
userName ↔ String
User name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited