MessageSearchResultItem class

Constructors

MessageSearchResultItem({String conversationID = '', String conversationShowName = '', String? conversationAvatarURL, int messageCount = 0, List<MessageInfo> messageList = const []})

Properties

conversationAvatarURL ↔ String?
getter/setter pair
conversationID ↔ String
getter/setter pair
conversationShowName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageCount ↔ int
getter/setter pair
messageList ↔ List<MessageInfo>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited