SubscriptionToken class

订阅令牌,用于取消 EngineBridge.subscribe 注册的事件监听。

Constructors

SubscriptionToken(String eventName, EngineEventHandler handler)
const

Properties

eventName String
final
handler EngineEventHandler
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited