LiveJsonUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
intToDeviceControlPolicy(
int? value) → DeviceControlPolicy -
intToDeviceStatus(
int? value) → DeviceStatus -
mapToAVStatistics(
Map< String, dynamic> ? map) → AVStatistics -
mapToLiveCanvas(
Map< String, dynamic> ? map) → LiveCanvas -
mapToRegionInfo(
Map< String, dynamic> ? map) → RegionInfo -
mapToSeatInfo(
Map< String, dynamic> ? map) → SeatInfo -
mapToSeatUserInfo(
Map< String, dynamic> ? map) → SeatUserInfo