api/ai/ai_transcriber_store
library
Classes
-
AITranscriberStore
-
AI real-time transcription related interfaces, managing real-time speech-to-text transcription and translation features.
-
AITranscriberStoreListener
-
AI transcriber event callback.
-
TranscriberConfig
-
Transcription configuration, used to configure source language and translation languages.
-
TranscriberMessage
-
Transcription message, representing a single segment of transcribed speech.
-
TranscriberState
-
Transcription state data provided by AITranscriberStore.