CallState class abstract
Call state data, manages the real-time data state of the current call.
A comprehensive snapshot of the current call session state. This structure contains all relevant information about active calls, recent call records, participant lists, etc.
Note: Call state updates automatically. Subscribe to
stateto receive real-time updates.
State Properties Overview
| Property | Type | Description |
|---|---|---|
activeCall |
ValueListenable<CallInfo> |
Current active call information |
recentCalls |
ValueListenable<List<CallInfo>> |
Recent call records list |
cursor |
ValueListenable<String> |
Pagination cursor |
selfInfo |
ValueListenable<CallParticipantInfo> |
Current user's own information |
allParticipants |
ValueListenable<List<CallParticipantInfo>> |
All participants in current call |
speakerVolumes |
ValueListenable<Map<String, int>> |
Participant volume information |
networkQualities |
ValueListenable<Map<String, NetworkQuality>> |
Participant network quality information |
Constructors
Properties
-
activeCall
→ ValueListenable<
CallInfo> -
Current active call information
no setter
-
allParticipants
→ ValueListenable<
List< CallParticipantInfo> > -
All participants in current call
no setter
-
cursor
→ ValueListenable<
String> -
Pagination cursor, used to query more call records
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
networkQualities
→ ValueListenable<
Map< String, NetworkQuality> > -
Participant network quality information, key is user ID, value is network quality
no setter
-
recentCalls
→ ValueListenable<
List< CallInfo> > -
Recent call records list
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selfInfo
→ ValueListenable<
CallParticipantInfo> -
Current user's own information
no setter
-
speakerVolumes
→ ValueListenable<
Map< String, int> > -
Participant volume information, key is user ID, value is volume level
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited