DeviceState class abstract
Device state
A comprehensive snapshot of device state, containing all device-related status information including microphone, camera, screen sharing and network.
Note: Device state is automatically updated. Subscribe to
stateto receive real-time updates.
State Properties Overview
| Property | Type | Description |
|---|---|---|
| microphoneStatus | ValueListenable<DeviceStatus> |
Microphone status |
| microphoneLastError | ValueListenable<DeviceError> |
Microphone error |
| captureVolume | ValueListenable<int> |
Capture volume, range 0, 100 |
| currentMicVolume | ValueListenable<int> |
Current user's actual output volume |
| outputVolume | ValueListenable<int> |
Maximum output volume, range 0, 100 |
| cameraStatus | ValueListenable<DeviceStatus> |
Camera status |
| cameraLastError | ValueListenable<DeviceError> |
Camera error |
| isFrontCamera | ValueListenable<bool> |
Whether it's front camera |
| localMirrorType | ValueListenable<MirrorType> |
Mirror state |
| localVideoQuality | ValueListenable<VideoQuality> |
Local video quality |
| currentAudioRoute | ValueListenable<AudioRoute> |
Current audio route location |
| screenStatus | ValueListenable<DeviceStatus> |
Screen sharing status |
| networkInfo | ValueListenable<NetworkInfo> |
Network information |
Constructors
Properties
-
cameraLastError
→ ValueListenable<
DeviceError> -
Camera error, used to extract error information when an error occurs.
no setter
-
cameraStatus
→ ValueListenable<
DeviceStatus> -
Camera status.
no setter
-
captureVolume
→ ValueListenable<
int> -
Capture volume, range
0, 100.no setter -
currentAudioRoute
→ ValueListenable<
AudioRoute> -
Current audio route location.
no setter
-
currentMicVolume
→ ValueListenable<
int> -
Current user's actual output volume.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isFrontCamera
→ ValueListenable<
bool> -
Whether it's front camera.
no setter
-
localMirrorType
→ ValueListenable<
MirrorType> -
Mirror state.
no setter
-
localVideoQuality
→ ValueListenable<
VideoQuality> -
Local video quality.
no setter
-
microphoneLastError
→ ValueListenable<
DeviceError> -
Microphone error, used to extract error information when an error occurs.
no setter
-
microphoneStatus
→ ValueListenable<
DeviceStatus> -
Microphone status.
no setter
-
networkInfo
→ ValueListenable<
NetworkInfo> -
Network information.
no setter
-
outputVolume
→ ValueListenable<
int> -
Maximum output volume, range
0, 100.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screenStatus
→ ValueListenable<
DeviceStatus> -
Screen sharing status.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited