VideoQuality enum
Video quality level.
This enum defines the video capture quality levels. The SDK has built-in resolution, frame rate, and bitrate combinations for each level, making it easy to choose for different scenarios.
Different levels affect RTC service billing. For pricing details, please refer to: https://trtc.io/document/42734?product=pricing
Response Scenarios
| Quality | Value | Description |
|---|---|---|
quality360P |
1 | 640 x 360 |
quality540P |
2 | 960 x 540 |
quality720P |
3 | 1280 x 720 |
quality1080P |
4 | 1920 x 1080 |
Values
- quality360P → const VideoQuality
-
360P, resolution 640 x 360.
const VideoQuality(1) - quality540P → const VideoQuality
-
540P, resolution 960 x 540.
const VideoQuality(2) - quality720P → const VideoQuality
-
720P, resolution 1280 x 720.
const VideoQuality(3) - quality1080P → const VideoQuality
-
1080P, resolution 1920 x 1080.
const VideoQuality(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoQuality> - A constant List of the values in this enum, in order of their declaration.