MusicState class abstract

Music playback state, managing the playback data state of the current room.

Constructors

MusicState()

Properties

hashCode int
The hash code for this object.
no setterinherited
musicVolume ValueListenable<int>
BGM volume, range 0 - 100, default 60.
no setter
playProgress ValueListenable<int>
Current playback progress (unit: milliseconds).
no setter
playStatus ValueListenable<MusicPlayStatus>
Current playback status.
no setter
playURL ValueListenable<String?>
Currently playing music URL. null means no music is playing.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDuration ValueListenable<int>
Total duration of current music (unit: milliseconds). 0 means unknown.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited