api/gift/gift_store library
Classes
- Gift
- Gift data model, containing complete attribute information of a single gift.
- GiftCategory
- Gift category.
- GiftListener
- Gift event, used to receive gift dynamics in live rooms/voice chat rooms.
- GiftState
- Gift state, managing the gift data state of the current room, supporting real-time updates and subscription listening.
- GiftStore
- Gift-related interface, managing gift sending, gift state synchronization, and gift event listening in live rooms/voice chat rooms.