GroupApplicationInfo class
Constructors
- GroupApplicationInfo({required String applicationID, required String groupID, String? fromUser, String? fromUserNickname, String? fromUserAvatarURL, String? toUser, int addTime = 0, String? requestMsg, String? handledMsg, required GroupApplicationType type, GroupApplicationHandledStatus? handledStatus, GroupApplicationHandledResult? handledResult, V2TimGroupApplication? rawApplication})
Properties
- addTime → int
-
final
- applicationID → String
-
final
- fromUser → String?
-
final
- fromUserAvatarURL → String?
-
final
- fromUserNickname → String?
-
final
- groupID → String
-
final
- handledMsg → String?
-
final
- handledResult ↔ GroupApplicationHandledResult?
-
getter/setter pair
- handledStatus ↔ GroupApplicationHandledStatus?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestMsg → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toUser → String?
-
final
- type → GroupApplicationType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited