BattleConfig class
PK configuration information set when sending a PK request
PK configuration information for setting PK duration, whether response is needed, and other parameters.
| Property | Type | Description |
|---|---|---|
| duration | int |
{'PK duration (unit': 'seconds)'} |
| needResponse | bool |
Whether the invitee needs to reply with accept/reject |
| extensionInfo | String |
Extension information |
Constructors
- BattleConfig({int duration = 0, bool needResponse = false, String extensionInfo = ''})
Properties
- duration ↔ int
-
PK duration (unit: seconds).
getter/setter pair
- extensionInfo ↔ String
-
Extension information.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- needResponse ↔ bool
-
Whether the invitee needs to reply with accept/reject.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited