BattleInfo class
PK information
PK information, containing PK ID, configuration information, start time, and end time.
| Property | Type | Description |
|---|---|---|
| battleID | String |
PK ID |
| config | BattleConfig | PK configuration information |
| startTime | int |
{'PK start timestamp (unit': 'seconds)'} |
| endTime | int |
{'PK end timestamp (unit': 'seconds)'} |
Constructors
- BattleInfo({String battleID = '', BattleConfig? config, int startTime = 0, int endTime = 0})
Properties
- battleID → String
-
PK ID.
final
- config → BattleConfig
-
PK configuration information set when sending a PK request.
final
- endTime → int
-
PK end marker timestamp (unit: seconds).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → int
-
PK start marker timestamp (unit: seconds).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited