BattleRequestCompletionHandler class
PK request completion handler
Completion handler for PK requests in Dart, containing the result of the PK request.
- Inheritance
-
- Object
- CompletionHandler
- BattleRequestCompletionHandler
Constructors
Properties
- battleInfo ↔ BattleInfo?
-
PK information returned on success.
getter/setter pair
- errorCode ↔ int
-
Error code.
getter/setter pairinherited
- errorMessage ↔ String?
-
Error message description.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Whether successful.
no setterinherited
-
resultMap
↔ Map<
String, int> ? -
Response result mapping for PK request.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited