api/live/co_host_store library
Classes
- CoHostListener
- Connection request callback events
- CoHostState
- Cross-room connection related state data provided externally by CoHostStore
- CoHostStore
- Live host connection management related interfaces, managing creation, joining, leaving and other operations for host-to-host connections.
Enums
- CoHostLayoutTemplate
- Connection layout template
- CoHostStatus
- Current user's cross-room connection status