api/live/like_store library
Classes
- LikeListener
- Like event, used to receive like dynamics in live rooms/voice chat rooms.
- LikeState
- Like state, used to display and subscribe to like information in live rooms/voice chat rooms.
- LikeStore
- Like related interfaces, managing like sending, like state synchronization, and like event listening operations in live rooms/voice chat rooms.