GroupSearchInfo class
Constructors
- GroupSearchInfo({String groupID = '', GroupType groupType = GroupType.work, String? groupName, int memberCount = 0, String? groupAvatarURL, String? introduction, GroupJoinOption joinGroupApprovalType = GroupJoinOption.forbid, GroupInviteOption inviteToGroupApprovalType = GroupInviteOption.forbid})
Properties
- groupAvatarURL ↔ String?
-
getter/setter pair
- groupID ↔ String
-
getter/setter pair
- groupName ↔ String?
-
getter/setter pair
- groupType ↔ GroupType
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- introduction ↔ String?
-
getter/setter pair
- inviteToGroupApprovalType ↔ GroupInviteOption
-
getter/setter pair
- joinGroupApprovalType ↔ GroupJoinOption
-
getter/setter pair
- memberCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited