EngineBridge class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dispose(
) → Future< void> - 反初始化引擎,清空所有事件 / 查询处理器,并释放单例。
-
invoke(
String eventName, String jsonData, {String id = ''}) → Future< EngineCallResult> -
query(
String eventName, String jsonData, {String id = ''}) → String -
removeAll(
) → void - 清空所有订阅与查询处理器。
-
setQueryHandler(
String eventName, EngineQueryHandler handler) → void - 注册引擎 → Dart 的同步查询处理器(单播,覆盖写入)。
-
subscribe(
String eventName, EngineEventHandler handler) → SubscriptionToken - 订阅引擎 → Dart 的事件(被动回调,多播)。
-
unsubscribe(
SubscriptionToken token) → void - 取消由 subscribe 注册的事件监听。